pub fn parse_frag_header(payload: &[u8]) -> Option<FragmentHeader>Expand description
Parses the FragmentHeader from the start of a frame payload.
Returns None if the payload is shorter than FRAG_HEADER_SIZE.
pub fn parse_frag_header(payload: &[u8]) -> Option<FragmentHeader>Parses the FragmentHeader from the start of a frame payload.
Returns None if the payload is shorter than FRAG_HEADER_SIZE.