#[repr(i32)]pub enum CommandStatus {
CommandOk = 0,
CommandError = 1,
CommandUnknown = 2,
CommandPermissionDenied = 3,
}Variants
CommandOk = 0
CommandError = 1
CommandUnknown = 2
plugin doesn’t know this command
CommandPermissionDenied = 3
plugin didn’t declare PERMISSION_KERNEL_ADMIN
Implementations
Sourceimpl CommandStatus
impl CommandStatus
Sourceimpl CommandStatus
impl CommandStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.