pub struct AudioStreamChunk {
pub stream_id: u32,
pub codec: i32,
pub sample_rate: u32,
pub channels: u32,
pub data: Vec<u8>,
pub end_of_stream: bool,
}Fields
stream_id: u32identifies stream session; plugins assign this
codec: i32sample_rate: u32Hz: 16000, 44100, 48000
channels: u321 = mono, 2 = stereo
data: Vec<u8>raw PCM_S16LE or Opus packet
end_of_stream: boolsender signals stream closed
Implementations
Sourceimpl AudioStreamChunk
impl AudioStreamChunk
Sourcepub fn codec(&self) -> AudioCodec
pub fn codec(&self) -> AudioCodec
Returns the enum value of codec, or the default if the field is set to an invalid enum value.
Sourcepub fn set_codec(&mut self, value: AudioCodec)
pub fn set_codec(&mut self, value: AudioCodec)
Sets codec to the provided enum value.