pub struct KernelCommandAck {
pub command_id: String,
pub status: i32,
pub data_json: Vec<u8>,
pub error: String,
}Fields
command_id: Stringstatus: i32data_json: Vec<u8>error: StringImplementations
Sourceimpl KernelCommandAck
impl KernelCommandAck
Sourcepub fn status(&self) -> CommandStatus
pub fn status(&self) -> CommandStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: CommandStatus)
pub fn set_status(&mut self, value: CommandStatus)
Sets status to the provided enum value.